@@ -284,7 +284,7 @@ def get_bootstrap_samples(
             no. 1, 130--134. https://dx.doi.org/10.1214/aos/1176345338
     """
     if not type(data) == np.ndarray:
-        data = np.array(data)
+        data = np.array(data.to_numpy(dtype='float', na_value=np.nan))
 
     if np.isnan(data).any():
         raise ValueError("'data' contains null values")
